@@ -217,7 +217,7 @@ class RelationalDbHelper(BaseSqlHelper, ABC):
                 condition_sql = f"{condition_sql} {connector} {sql_segment}"
             else:
                 condition_sql = sql_segment
-            if value:
+            if value is not None:
                 if isinstance(value, list):
                     values.extend(value)
                 else:
