@@ -238,6 +238,10 @@ class JSONEncoder(json.JSONEncoder):
             return str(o)
         elif isinstance(o, datetime):
             return str(o)
+        elif isinstance(o, bytes):
+            return str(o, encoding="utf-8")
+        elif isinstance(o,set):
+            return list(o)
         return json.JSONEncoder.default(self, o)
 
 
